<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'Polski [pl]',
'0_liste' => 'spip-dev@rezo.net',
'0_mainteneur' => 'd.paszkiewicz@ekstenso.com',

// A
'access_interface_graphique' => 'Powr&oacute;t do pe&#322;nego interfejsu graficznego',
'access_mode_texte' => 'Uproszczony interfejs - tryb tekstowy',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Modyfikuj artyku&#322;',
'admin_modifier_auteur' => 'Modyfikuj autora',
'admin_modifier_breve' => 'Modyfikuj news',
'admin_modifier_mot' => 'Modyfikuj s&#322;owo kluczowe',
'admin_modifier_rubrique' => 'Modyfikuj dzia&#322;',
'admin_recalculer' => 'Od&#347;wie&#380; ',
'afficher_trad' => 'poka&#380; przek&#322;ady',
'alerte_maj_impossible' => '<MODIF><b>Uwaga!</b> Uaktualnienie bazy danych SQL do wersji @version@ jest nie mo&#380;liwe. Powodem jest prawdopodobnie brak mo&#380;liwo&#347;ci modyfikacji bazy danych. Skontaktuj si&#281; z administratorem.',
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute;e par ailleurs. La valeur actuelle est&nbsp;:', # NEW
'analyse_xml' => 'Analiza XML',
'annuler' => 'Anuluj',
'antispam_champ_vide' => 'Pozostaw puste:',
'articles_recents' => 'Najnowsze artyku&#322;y',
'avis_archive_incorrect' => 'ten plik archiwalny nie nale&#380;y do SPIP',
'avis_archive_invalide' => 'plik archiwalny jest nieprawid&#322;owy',
'avis_attention' => 'UWAGA&nbsp;!',
'avis_champ_incorrect_type_objet' => 'Nieprawi&#322;owa nazwa pola @name@ dla obiektu typu @type@',
'avis_colonne_inexistante' => 'Kolumna @col@ nie istnieje',
'avis_echec_syndication_01' => 'Syndykacja nie powiod&#322;a si&#281; : plik backend jest nieodczytywalny lub nie ma w nim &#380;adnego artyku&#322;u.',
'avis_echec_syndication_02' => 'Syndykacja nie powiod&#322;a si&#281; : nie ma dost&#281;pu do pliku backend tego serwisu.',
'avis_erreur' => 'B&#322;&#261;d: zobacz poni&#380;ej\';',
'avis_erreur_connexion' => 'B&#322;&#261;d po&#322;&#261;czenia',
'avis_erreur_cookie' => 'problem z cookie',
'avis_erreur_fonction_contexte' => 'B&#322;&#261;d programistyczny. Ta funkcja nie powinna by&#263; wywo&#322;ywana w tym kontek&#347;cie.',
'avis_erreur_mysql' => 'B&#322;&#261;d SQL',
'avis_erreur_sauvegarde' => 'B&#322;&#261;d archiwizacji (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Problem z dost&#281;pem do stron administracyjnych',

// B
'barre_a_accent_grave' => 'Wstaw du&#380;&#261; liter&#281; A z akcentem grave',
'barre_aide' => 'U&#380;yj skr&oacute;t&oacute;w typograficznych do ulepszenia layoutu',
'barre_e_accent_aigu' => 'Wstaw du&#380;&#261; liter&#281; E z akcentem acute',
'barre_eo' => 'Wstaw ligatur&#281; oe',
'barre_eo_maj' => 'Wstaw du&#380;&#261; ligatur&#281; EO',
'barre_euro' => 'Umie&#347;&#263; symbol &euro;€',
'barre_gras' => 'Wstaw w {{boldzie}}',
'barre_guillemets' => 'Umie&#347;&#263; w "cudzys&#322;owie"',
'barre_guillemets_simples' => 'Umie&#347;&#263; w innym “cudzys&#322;owie”',
'barre_intertitre' => 'Przekszta&#322;&#263; w {{{&#347;r&oacute;dtytu&#322;}}}',
'barre_italic' => 'Wstaw w {italiku}',
'barre_lien' => 'Zmie&#324; w [hiper&#322;&#261;cze->http://...]',
'barre_lien_input' => 'Prosz&#281; wpisa&#263; cel hiper&#322;&#261;cza (mo&#380;e to by&#263; URL internetowy w formie http://www.mysite.com lub po prostu numer artyku&#322;u na tej stronie).',
'barre_note' => 'Zmie&#324; w [[Przypis]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
'barre_quote' => '<quote>Zacytuj wiadomo&#347;&#263;</quote>',
'bouton_ajouter_document' => 'DODAJ DOKUMENT', # MODIF
'bouton_ajouter_image' => 'DODAJ OBRAZEK', # MODIF
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
'bouton_changer' => 'Zatwierd&#378;',
'bouton_chercher' => 'Szukaj',
'bouton_choisir' => 'Wybierz',
'bouton_download' => '&#346;ci&#261;gnij',
'bouton_enregistrer' => 'Zapisz',
'bouton_radio_desactiver_messagerie_interne' => 'Dezaktywuj poczt&#281; wewn&#281;trzn&#261;',
'bouton_radio_envoi_annonces' => 'Wy&#347;lij og&#322;oszenia redakcyjne',
'bouton_radio_non_envoi_annonces' => 'Nie wysy&#322;aj &#380;adnych zawiadomie&#324;',
'bouton_radio_non_envoi_liste_nouveautes' => 'Nie wysy&#322;aj najnowszej listy news&oacute;w',
'bouton_recharger_page' => 'ponownie za&#322;aduj t&#281; stron&#281;',
'bouton_telecharger' => 'Za&#322;aduj',
'bouton_valider' => 'Zatwierd&#378;',

// C
'cal_apresmidi' => 'popo&#322;udniu',
'cal_jour_entier' => 'ca&#322;y dzie&#324;',
'cal_matin' => 'rano',
'cal_par_jour' => 'wg dni',
'cal_par_mois' => 'wg miesi&#281;cy',
'cal_par_semaine' => 'wg tygodni',
'choix_couleur_interface' => 'kolor',
'choix_interface' => 'wyb&oacute;r interfejsu',
'colonne' => 'Kolumna',
'confirm_changer_statut' => 'Uwaga, czy na pewno chcesz zmieni&#263; status tego elementu ? Kontynuowa&#263; ?',
'correcte' => 'poprawna',

// D
'date_aujourdhui' => 'dzi&#347;',
'date_avant_jc' => 'P.N.E.',
'date_dans' => 'w @delai@',
'date_de_mois_1' => '@j@ stycznia',
'date_de_mois_10' => '@j@ pa&#378;dziernika',
'date_de_mois_11' => '@j@ listopada',
'date_de_mois_12' => '@j@ grudnia',
'date_de_mois_2' => '@j@ lutego',
'date_de_mois_3' => '@j@ marca',
'date_de_mois_4' => '@j@ kwietnia',
'date_de_mois_5' => '@j@ maja',
'date_de_mois_6' => '@j@ czerwca',
'date_de_mois_7' => '@j@ lipca',
'date_de_mois_8' => '@j@ sierpnia',
'date_de_mois_9' => '@j@ wrze&#347;nia',
'date_demain' => 'jutro',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ o @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => '@date@ @nomjour@ ',
'date_heures' => 'godziny',
'date_hier' => 'wczoraj',
'date_il_y_a' => 'jest @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Niedziela',
'date_jour_1_abbr' => 'nie.',
'date_jour_1_initiale' => 'n.',
'date_jour_2' => 'Poniedzia&#322;ek',
'date_jour_2_abbr' => 'pon.',
'date_jour_2_initiale' => 'p.',
'date_jour_3' => 'Wtorek',
'date_jour_3_abbr' => 'wto.',
'date_jour_3_initiale' => 'w.',
'date_jour_4' => '&#346;roda',
'date_jour_4_abbr' => '&#347;ro.',
'date_jour_4_initiale' => '&#347;.',
'date_jour_5' => 'Czwartek',
'date_jour_5_abbr' => 'czw.',
'date_jour_5_initiale' => 'c.',
'date_jour_6' => 'Pi&#261;tek',
'date_jour_6_abbr' => 'pi&#261;.',
'date_jour_6_initiale' => 'p.',
'date_jour_7' => 'Sobota',
'date_jour_7_abbr' => 'sob.',
'date_jour_7_initiale' => 's.',
'date_jours' => 'dni',
'date_minutes' => 'minuty',
'date_mois' => 'miesi&#261;c',
'date_mois_1' => 'Stycze&#324;',
'date_mois_10' => 'Pa&#378;dziernik',
'date_mois_11' => 'Listopad',
'date_mois_12' => 'Grudzie&#324;',
'date_mois_2' => 'Luty',
'date_mois_3' => 'Marzec',
'date_mois_4' => 'Kwiecie&#324;',
'date_mois_5' => 'Maj',
'date_mois_6' => 'Czerwiec',
'date_mois_7' => 'Lipiec',
'date_mois_8' => 'Sierpie&#324;',
'date_mois_9' => 'Wrzesie&#324;',
'date_saison_1' => 'zima',
'date_saison_2' => 'wiosna',
'date_saison_3' => 'lato',
'date_saison_4' => 'jesie&#324;',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'tygodnie',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => ' w celu rzeczywistego rozpocz&#281;cia instalacji',
'dirs_preliminaire' => 'Wst&#281;p: <b>Ustawienia pozwole&#324; dost&#281;pu</b>',
'dirs_probleme_droits' => 'Problem z prawami dost&#281;pu',
'dirs_repertoires_absents' => '<p><b>Nast&#281;puj&#261;ce katalogi nie zosta&#322;y odnalezione&nbsp;:</b></p> <ul>@bad_dirs@.</ul> 
  <p>Mo&#380;liwe, &#380;e powodem tego jest nazwa, w kt&oacute;rej pomylone zosta&#322;y du&#380;e i ma&#322;e litery.
  Sprawd&#378; nazwy pod wzgl&#281;dem ma&#322;ych i du&#380;ych liter.
  Je&#347;li rzeczywi&#347;cie wielko&#347;&#263; liter jest r&oacute;&#380;na, zmie&#324; nazwy katalog&oacute;w za pomoc&#261; dowolnego programu FTP
  <p>Po wykonaniu tej operacji b&#281;dziesz m&oacute;g&#322;',
'dirs_repertoires_suivants' => '<p><b>Nast&#281;puj&#261;ce katalogi nie s&#261; skonfigurowane do zapisu&nbsp;:</b></p> <ul>@bad_dirs@.</ul> 
  <p>Aby temu zapobiec, skorzystaj z klienta FTP i ureguluj konieczne prawa dost&#281;pu
  do tych katalog&oacute;w. Procedura jest wyt&#322;umaczona od A-Z w przewodniku instalacji.
  <p>Kiedy dokonasz koniecznych zmian, b&#281;dziesz m&oacute;g&#322;',
'double_occurrence' => 'Podw&oacute;jne wyst&#261;pienie', # MODIF

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Rozmiar:',
'entree_titre_document' => 'Tytu&#322; dokumentu:',
'entree_titre_image' => 'Tytu&#322; obrazka:',
'envoi_via_le_site' => 'Wy&#347;lij ze strony',
'erreur' => 'B&#322;&#261;d',
'erreur_balise_non_fermee' => 'ostatni znacznik nie jest zamkni&#281;ty :',
'erreur_texte' => 'b&#322;&#261;d/b&#322;&#281;dy',
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'Plik @fichier@ nie odnaleziony',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Jeste&#347; ju&#380; zarejestrowany.',
'form_email_non_valide' => 'Tw&oacute;j adres e-mail nie jest prawid&#322;owy.',
'form_forum_access_refuse' => 'Nie masz ju&#380; dost&#281;pu do tej strony.',
'form_forum_bonjour' => 'Witaj @nom@,',
'form_forum_email_deja_enregistre' => 'Ten adres e-mail jest ju&#380; zarejestrowany, wskutek czego nie mo&#380;esz u&#380;ywa&#263; swojego zwyk&#322;ego has&#322;a.',
'form_forum_identifiant_mail' => 'Tw&oacute;j nowy identyfikator zosta&#322; w&#322;a&#347;nie wys&#322;any do Ciebie e-mailem.',
'form_forum_identifiants' => 'Osobista identyfikacja',
'form_forum_indiquer_nom_email' => 'Wpisz tutaj swoje nazwisko i adres e-mail. Wkr&oacute;tce otrzymasz e-mailem sw&oacute;j osobisty identyfikator.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(to jest wiadomo&#347;&#263; automatyczna)',
'form_forum_pass' => 'has&#322;o:',
'form_forum_probleme_mail' => 'Problem z poczt&#261;: Tw&oacute;j identyfikator nie mo&#380;e zosta&#263; wys&#322;any.',
'form_forum_voici1' => 'Oto Tw&oacute;je dane, kt&oacute;re pozwol&#261; Ci wzi&#261;&#263; udzia&#322; w rozwoju serwisu
"@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Oto Tw&oacute;j identyfikator do proponowania artyku&#322;&oacute;w w
serwisie "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Prosz&#281; wpisa&#263; sw&oacute;j adres e-mail.',
'form_indiquer_nom' => 'Prosz&#281; wpisa&#263; swoje nazwisko.',
'form_indiquer_nom_site' => 'Prosz&#281; wpisa&#263; nazw&#281; swoich stron\\y.',
'form_pet_adresse_site' => 'URL Twojej strony',
'form_pet_aucune_signature' => '&#379;aden podpis nie odpowiada podanemu kodowi...',
'form_pet_confirmation' => 'Prosz&#281; potwierdzi&#263; sw&oacute;j podpis:',
'form_pet_deja_enregistre' => 'Ta strona jest ju&#380; zarejestrowana',
'form_pet_deja_signe' => 'Ju&#380; podpisa&#322;e&#347; ten tekst.',
'form_pet_envoi_mail_confirmation' => 'E-mail potwierdzaj&#261;cy zosta&#322; w&#322;a&#347;nie do Ciebie wys&#322;any. Odwied&#378; URL wymienione w mailu, aby zatwierdzi&#263; sw&oacute;j podpis.', # MODIF
'form_pet_mail_confirmation' => 'Witamy,

Zg&#322;osi&#322;e&#347; ch&#281;&#263; podpisania petycji:
@titre@.

Poda&#322;e&#347; nast&#281;puj&#261;ce informacje:
    Name: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

WA&#379;NE...
Aby zatwierdzi&#263; sw&oacute;j podpis, musisz po&#322;&#261;czy&#263; si&#281; z
poni&#380;szym adresem (w przeciwnym razie, Twoja pro&#347;ba
zostanie odrzucona):

    @url@


Dzi&#281;kujemy za wzi&#281;cie udzia&#322;u.
',
'form_pet_message_commentaire' => 'Jakie&#347; wiadomo&#347;ci lub komentarze?',
'form_pet_nom_site2' => 'Nazwa Twojej strony internetowej',
'form_pet_probleme_liens' => 'Spr&oacute;buj wys&#322;a&#263; wiadomo&#347;&#263; po usuni&#281;ciu link&oacute;w.',
'form_pet_probleme_technique' => 'Problem techniczny, podpisy s&#261; tymczasowo zawieszone.',
'form_pet_signature_pasprise' => 'Tw&oacute;j podpis zosta&#322; zlekcewa&#380;ony.',
'form_pet_signature_validee' => 'Tw&oacute;j podpis zosta&#322; zatwierdzony. Dzi&#281;kujemy!',
'form_pet_site_deja_enregistre' => 'Ta strona jest ju&#380; zarejestrowana',
'form_pet_url_invalide' => 'Wpisany URL nie jest prawid&#322;owy.',
'form_pet_votre_email' => 'Tw&oacute;j adres e-mail ',
'form_pet_votre_nom' => 'Twoje imi&#281; lub alias',
'form_pet_votre_site' => 'Jesli masz stron&#281; internetow&#261;, mo&#380;esz wpisa&#263; j&#261; poni&#380;ej',
'form_prop_confirmer_envoi' => 'Potwierd&#378; wys&#322;anie',
'form_prop_description' => 'Opis/komentarz',
'form_prop_enregistre' => 'Twoja propozycja zosta&#322;a zapisana, pojawi si&#281; online po jej zatwierdzeniu przez administratora tej strony.',
'form_prop_envoyer' => 'Wy&#347;lij wiadomo&#347;&#263;',
'form_prop_indiquer_email' => 'Prosz&#281; wpisa&#263; prawid&#322;owy adres e-mail',
'form_prop_indiquer_nom_site' => 'Prosz&#281; wpisa&#263; nazw&#281; strony.',
'form_prop_indiquer_sujet' => 'Prosz&#281; wpisa&#263; temat',
'form_prop_message_envoye' => 'Wiadomo&#347;&#263; wys&#322;ana',
'form_prop_nom_site' => 'Nazwa stron\\y',
'form_prop_non_enregistre' => 'Twoja propozycja nie zosta&#322;a zapisana.',
'form_prop_sujet' => 'Temat',
'form_prop_url_site' => 'URL stron\\y',
'forum_acces_refuse' => 'Nie masz ju&#380; dost&#281;pu do tego forum.',
'forum_attention_dix_caracteres' => '<b>Uwaga!</b> Twoja wiadomo&#347;&#263; powinna mie&#263; conajmniej 10 znak&oacute;w.',
'forum_attention_trois_caracteres' => '<b>Uwaga!</b> Tw&oacute;j temat powinien mie&#263; conajmniej 3 znaki.',
'forum_attention_trop_caracteres' => '<b>Uwaga&nbsp;!</b> Twoja wiadomo&#347;&#263; jest za d&#322;uga(@compte@ znak&oacute;w)&nbsp;: aby mog&#322;a zosta&#263; przyj&#281;ta nie mo&#380;e przekracza&#263; @max@ znak&oacute;w.',
'forum_avez_selectionne' => 'Wybra&#322;e&#347;:',
'forum_cliquer_retour' => 'Kliknij <a href=\'@retour_forum@\'>tutaj</a> aby kontynuowa&#263;.',
'forum_forum' => 'forum',
'forum_info_modere' => 'To forum jest moderowane&nbsp;: Tw&oacute;j wpis uka&#380;e si&#281; dopiero po weryfikacji przez administratora strony.',
'forum_lien_hyper' => '<b>Link</b> (opcjonalny)',
'forum_message_definitif' => 'Wiadomo&#347;&#263; ko&#324;cowa: wy&#347;lij na stron&#281;',
'forum_message_trop_long' => 'Twoja wiadomo&#347;&#263; jest za d&#322;uga. Maksymalna d&#322;ugo&#347;&#263; to 20000 znak&oacute;w.',
'forum_ne_repondez_pas' => 'Nie odpowiadaj na tego maila, lecz na forum, pod nast&#281;puj&#261;cym adresem:',
'forum_non_inscrit' => 'Nie jeste&#347; zarejestrowany, lub adres b&#261;d&#378; has&#322;o s&#261; nieprawid&#322;owe.',
'forum_page_url' => '(Je&#347;li twoja wiadomo&#347;&#263; odnosi si&#281; jakiego&#347; artyku&#322;y opublikowanego w internecie, wpisz poni&#380;ej tytu&#322; tej strony oraz jej adres).',
'forum_par_auteur' => 'wg @auteur@',
'forum_poste_par' => 'Wiadomo&#347;&#263; na temat twojego artyku&#322;u napisana przez@parauteur@.',
'forum_probleme_database' => 'Problem z baz&#261; danych, Twoja wiadomo&#347;&#263; nie mog&#322;a by&#263; zapisana.',
'forum_qui_etes_vous' => '<b>Kim jeste&#347;?</b> (nieobowi&#261;zkowe)',
'forum_texte' => 'Tekst Twojej wiadomo&#347;ci:',
'forum_titre' => 'Temat:',
'forum_titre_erreur' => 'B&#322;&#261;d...',
'forum_url' => 'URL:',
'forum_valider' => 'Zatwierd&#378; ten wyb&oacute;r',
'forum_voir_avant' => 'Podgl&#261;d wiadomo&#347;ci przed umieszczeniem na forum',
'forum_votre_email' => 'Tw&oacute;j adres e-mail:',
'forum_votre_nom' => 'Twoje imi&#281; (lub alias):',
'forum_vous_enregistrer' => 'Aby uczestniczy&#263; w
  tym forum - musisz si&#281; zarejestrowa&#263; Dzi&#281;kuj&#281;
  za wprowadzenie loginu
  o kt&oacute;ry prosimy. Je&#347;li nie jeste&#347; jeszcze zarejstrowany, musisz',
'forum_vous_inscrire' => 'si&#281; zarejestrowa&#263;.',

// I
'ical_texte_rss_articles' => 'Plik "backend" artyku&#322;&oacute;w tej strony znajduje si&#281; pod adresem:',
'ical_texte_rss_articles2' => 'Mo&#380;esz r&oacute;wnie&#380; otrzyma&#263; pliki "backend" dla artyku&#322;&oacute;w dla ka&#380;dego z dzia&#322;&oacute;w strony:',
'ical_texte_rss_breves' => 'Istnieje tak&#380;e plik zawieraj&#261;cy wszystkie newsy opublikowane na stronie. Precyzuj&#261;c numer dzia&#322;u, otrzymasz newsy opublikowane w tym dziale.',
'icone_a_suivre' => 'Aktualno&#347;ci',
'icone_admin_site' => 'Administracja strony',
'icone_agenda' => 'Kalendarz',
'icone_aide_ligne' => 'Pomoc',
'icone_articles' => 'Artyku&#322;y',
'icone_auteurs' => 'Autorzy',
'icone_breves' => 'Newsy',
'icone_brouteur' => 'Menu podr&#281;czne',
'icone_configuration_site' => 'Konfiguracja',
'icone_configurer_site' => 'Konfiguruj swoj&#261; stron&#281;',
'icone_creer_nouvel_auteur' => 'Utw&oacute;rz nowego autora',
'icone_creer_rubrique' => 'Utw&oacute;rz dzia&#322;',
'icone_creer_sous_rubrique' => 'Utw&oacute;rz poddzia&#322;',
'icone_deconnecter' => 'Roz&#322;&#261;cz',
'icone_discussions' => 'Dyskusje',
'icone_doc_rubrique' => 'Za&#322;&#261;czniki',
'icone_ecrire_article' => 'Napisz nowy artyku&#322;',
'icone_edition_site' => 'Edycja',
'icone_forum_administrateur' => 'Forum administrator&oacute;w',
'icone_forum_suivi' => 'Kontynuacja forum',
'icone_gestion_langues' => 'Zarz&#261;dzanie j&#281;zykami',
'icone_informations_personnelles' => 'Informacje osobiste',
'icone_interface_complet' => 'ca&#322;y interfejs',
'icone_interface_simple' => 'Uproszczony interfejs',
'icone_maintenance_site' => 'Administracja stron&#261;',
'icone_messagerie_personnelle' => 'Wiadomo&#347;ci prywatne',
'icone_mots_cles' => 'S&#322;owa kluczowe',
'icone_nouvelle_breve' => 'Napisz nowy news',
'icone_repartition_actuelle' => 'Poka&#380; aktualn&#261; dystrybucj&#281;',
'icone_repartition_debut' => 'Poka&#380; dystrybucj&#281; od pocz&#261;tku',
'icone_repartition_visites' => 'Roz&#322;o&#380;enie wizyt',
'icone_rubriques' => 'Dzia&#322;y',
'icone_sauver_site' => 'Backup strony',
'icone_site_entier' => 'Ca&#322;a strona',
'icone_sites_references' => 'Zlinkowane strony',
'icone_statistiques' => 'Statystyki strony',
'icone_statistiques_visites' => 'Statystyki',
'icone_suivi_activite' => 'Prace redakcyjne',
'icone_suivi_actualite' => 'Rozw&oacute;j strony',
'icone_suivi_forums' => 'Zarz&#261;dzanie forum',
'icone_suivi_pettions' => '&#346;led&#378;/zarz&#261;dzaj og&#322;oszeniami',
'icone_suivi_revisions' => 'Zmiany artyku&#322;&oacute;w',
'icone_supprimer_document' => 'Usu&#324; ten dokument',
'icone_supprimer_image' => 'Usu&#324; ten obrazek',
'icone_supprimer_message' => 'Usu&#324; t&#281; wiadomo&#347;&#263;',
'icone_tous_articles' => 'Wszystkie Twoje artyku&#322;y',
'icone_tous_auteur' => 'Wszyscy autorzy',
'icone_valider_message' => 'Zatwierd&#378; t&#281; wiadomo&#347;&#263;',
'icone_visiter_site' => 'Odwied&#378;',
'icone_voir_en_ligne' => 'Obejrzyj online',
'image_tourner_180' => 'Obr&oacute;t o 180&deg;',
'image_tourner_droite' => 'Obr&oacute;t o 90&deg; w prawo',
'image_tourner_gauche' => 'Obr&oacute;t o 90&deg; w lewo',
'img_indisponible' => 'obrazek niedost&#281;pny',
'impossible' => 'niemo&#380;liwe',
'info_a_suivre' => 'KONTYNUUJ&nbsp;&raquo;',
'info_a_valider' => '[do zatwierdzenia]',
'info_acces_interdit' => 'Dost&#281;p zabroniony',
'info_acces_refuse' => 'Brak dost&#281;pu',
'info_action' => 'Akcja: @action@',
'info_administrer_rubriques' => 'Mo&#380;esz zarz&#261;dza&#263; t&#261; dzia&#322;ami i jej poddzia&#322;ami',
'info_adresse_non_indiquee' => 'Nie poda&#322;e&#347; adresu testowego!',
'info_aide' => 'POMOC:',
'info_ajouter_mot' => 'Dodaj to s&#322;owo kluczowe',
'info_annonce' => 'ZAWIADOMIENIE',
'info_annonces_generales' => 'Og&oacute;lne og&#322;oszenia:',
'info_article_propose' => 'Zaproponowany artyku&#322;',
'info_article_publie' => 'Artyku&#322; opublikowany',
'info_article_redaction' => 'Artyku&#322; w trakcie tworzenia',
'info_article_refuse' => 'Artyku&#322; odrzucony',
'info_article_supprime' => 'Artyku&#322; usuni&#281;ty',
'info_articles' => 'Artyku&#322;y',
'info_articles_a_valider' => 'Artyku&#322;y do zatwierdzenia',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Zaproponowane artyku&#322;y',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autor(zy):',
'info_authentification_ftp' => 'Uwierzytelnienie (poprzez FTP).',
'info_bloquer_lien' => 'zablokuj ten link',
'info_breves_02' => 'Newsy',
'info_breves_2' => 'newsy',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Newsy do zatwierdzenia',
'info_connexion_refusee' => 'Brak po&#322;&#261;czenia',
'info_contact_developpeur' => 'Prosz&#281; skontaktowa&#263; si&#281; z deweloperem.',
'info_contenance' => 'Ta strona zawiera:',
'info_contribution' => 'wpisy na forum',
'info_copyright' => '@spip@ - darmowe oprogramowanie dystrybuowane w oparciu o licencj&#281; @lien_gpl@.',
'info_copyright_doc' => 'Wi&#281;cej informacji na stronie <a href="@spipnet@">http://www.spip.net</a>.', # MODIF
'info_copyright_gpl' => 'na licencji GPL',
'info_cours_edition' => 'Twoje artyku&#322;y w trakcie redagowania',
'info_creer_repertoire' => 'Utw&oacute;rz plik lub katalog o nazwie:',
'info_creer_repertoire_2' => 'w podkatalogu <b>@repertoire@</b>, a nast&#281;pnie:',
'info_creer_vignette' => 'generowanie miniaturki',
'info_deplier' => 'Rozwi&#324;',
'info_descriptif_nombre' => 'opis(y):',
'info_description' => 'Opis:',
'info_description_2' => 'Opis:',
'info_dimension' => 'Rozmiar:',
'info_document' => 'Dokument',
'info_document_indisponible' => 'Dokument niedost&#281;pny',
'info_documents' => 'Dokumenty',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP pozwala na wymian&#281; wiadomo&#347;ci i utworzenie Forum dyskusyjnego
  prywatnie pomi&#281;dzy u&#380;ytkownikami tej strony. Mo&#380;esz w&#322;&#261;czy&#263; lub wy&#322;&#261;czy&#263;
  t&#281; funkcj&#281;.',
'info_ecire_message_prive' => 'Napisz prywatn&#261; wiadomo&#347;&#263;',
'info_email_invalide' => 'Nieprawid&#322;owy adres e-mail.',
'info_en_cours_validation' => 'Twoje artyku&#322;y s&#261; w trakcie redagowania',
'info_en_ligne' => 'Teraz online:',
'info_envoyer_message_prive' => 'Wy&#347;lij prywatn&#261; wiadomo&#347;&#263; do tego autora',
'info_erreur_requete' => 'B&#322;&#261;d zapytania :',
'info_erreur_squelette2' => '&#379;aden szkielet <b>@fichier@</b> nie jest dost&#281;pny ...',
'info_erreur_systeme' => 'B&#322;&#261;d systemu (errno @errsys@)',
'info_erreur_systeme2' => 'Albo dysk twardy jest pe&#322;ny albo uszkodzona jest baza danych. <br />
 <font color=\'red\'>Spr&oacute;buj <a href=\'@script@\'>naprawi&#263; baz&#281; danych</a>,
 lub skontaktuj si&#281; z administratorem serwera.</font>',
'info_fini' => 'Zako&#324;czono!',
'info_format_image' => 'Formaty plik&oacute;w obrazk&oacute;w, kt&oacute;re mog&#261; by&#263; u&#380;ywane do tworzenia minitaturek&nbsp;: @gd_formats@.',
'info_format_non_defini' => 'format niezdefiniowany',
'info_grand_ecran' => 'Ca&#322;y ekran',
'info_image_aide' => 'POMOC',
'info_image_process_titre' => 'Spos&oacute;b generowania miniaturek',
'info_impossible_lire_page' => '<b>B&#322;&#261;d !</b> Nie mo&#380;na odczyta&#263; strony<tt><html>@test_proxy@</html></tt> za po&#347;rednictwem proxy<tt>',
'info_inclusion_directe' => 'Bezpo&#347;rednie do&#322;&#261;czenie&nbsp;:',
'info_inclusion_vignette' => 'Do&#322;&#261;czenie miniaturki&nbsp;:',
'info_installation_systeme_publication' => 'Instalacja systemu publikacji...',
'info_installer_documents' => 'Mo&#380;esz automatycznie dodawa&#263; wszystkie dokumenty znajduj&#261;ce si&#281; w folderze @upload@.',
'info_installer_ftp' => 'Jako administrator mo&#380;esz umieszcza&#263; (przez FTP) pliki w folderze @upload@, aby p&oacute;&#378;niej wybiera&#263; je bezpo&#347;rednio st&#261;d.',
'info_installer_images' => 'Mo&#380;esz umieszcza&#263; obrazki w formatach JPEG, GIF i PNG.',
'info_installer_images_dossier' => 'Umie&#347;&#263; obrazki w folderze @upload@ aby m&oacute;c je st&#261;d wybiera&#263;.',
'info_installer_tous_documents' => 'Umie&#347;&#263; wszystkie dokumenty',
'info_interface_complete' => 'ca&#322;y interfejs',
'info_interface_simple' => 'Uproszczony interfejs',
'info_joindre_document_article' => 'Do tego artyku&#322;u mo&#380;esz za&#322;&#261;cza&#263; dokumenty typu',
'info_joindre_document_rubrique' => 'Do tego dzia&#322;u mo&#380;esz dodawa&#263; dokumenty typu',
'info_joindre_documents_article' => 'Do swojego atyku&#322;u mo&#380;esz za&#322;&#261;cza&#263; dokumenty typu:',
'info_l_article' => 'artyku&#322;',
'info_la_breve' => 'news',
'info_la_rubrique' => 'dzia&#322;',
'info_langue_principale' => 'J&#281;zyk g&#322;&oacute;wnej strony',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pikseli',
'info_les_auteurs_1' => 'wg @les_auteurs@',
'info_logo_format_interdit' => 'Dla logo dozwolone s&#261; nast&#281;puj&#261;ce formaty: @formats@.',
'info_logo_max_poids' => 'Logo mo&#380;e mie&#263; maksymalnie @maxi@ (teraz ma @actuel@).',
'info_logo_max_taille' => 'Logo mo&#380;e mie&#263; maksymaln&#261; wielko&#347;&#263; @maxi@ (teraz ma wielko&#347;&#263; @actuel@).',
'info_mail_fournisseur' => 'you@isp.com',
'info_message_2' => 'WIADOMO&#346;&#262;',
'info_message_supprime' => 'WIADOMO&#346;&#262; USUNI&#280;TA',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Data publikacji online:',
'info_modification_parametres_securite' => 'modyfikacja parametr&oacute;w bezpiecze&#324;stwa',
'info_mois_courant' => 'Bie&#380;&#261;cy miesi&#261;c:',
'info_mot_cle_ajoute' => 'Nast&#281;puj&#261;ce s&#322;owo kluczowe dodane zosta&#322;o do',
'info_multi_herit' => 'J&#281;zyk domy&#347;lny',
'info_multi_langues_soulignees' => '<u>Podkre&#347;lonie j&#281;zyka</u> &#347;wiadczy o kompletnym przek&#322;adzie wszystkich tekst&oacute;w interfejsu. Je&#347;li wybierzesz jeden z tych j&#281;zyk&oacute;w, elementy serwisu (daty, formularze) zostan&#261; automatycznie przet&#322;umaczone. W przypadku j&#281;zyk&oacute;w nie-podkre&#347;lonych, elementy te uka&#380;&#261; si&#281; w g&#322;&oacute;wnym j&#281;zyku serwisu.', # MODIF
'info_multilinguisme' => 'Wieloj&#281;zyczny',
'info_nom_non_utilisateurs_connectes' => 'Twoja nazwa nie pojawia si&#281; na li&#347;cie pod&#322;&#261;czonych u&#380;ytkownik&oacute;w.',
'info_nom_utilisateurs_connectes' => 'Twoje imi&#281; wyst&#281;puje na li&#347;cie pod&#322;&#261;czonych u&#380;ytkownik&oacute;w.',
'info_nombre_en_ligne' => 'Teraz online:',
'info_non_resultat' => '&#379;adnych wynik&oacute;w dla "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Nie korzystasz z wewn&#281;trznej komunikacji tego serwisu.',
'info_nouveau_message' => 'MASZ NOW&#260; WIADOMO&#346;&#262;',
'info_nouveaux_messages' => 'MASZ @total_messages@ NOWYCH WIADOMO&#346;CI',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Strona syndykowana nie dzia&#322;a',
'info_pense_bete' => 'NOTATKA',
'info_petit_ecran' => 'Ma&#322;e okno',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'piksele',
'info_plusieurs_mots_trouves' => 'Kilkana&#347;cie s&#322;&oacute;w kluczowych zosta&#322;o znalezionych dla "@cherche_mot@":',
'info_popularite_5' => 'popularno&#347;&#263;:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'Automatyczne portfolio:',
'info_premier_resultat' => '[@debut_limit@ pierwsze wyniki z @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ pierwsze wyniki z @total@]',
'info_probleme_grave' => 'b&#322;&#261;d',
'info_propose_1' => '[@nom_site_spip@] Zatwierdza: @titre@',
'info_propose_2' => 'Artyku&#322;y zatwierdzone
-----------------',
'info_propose_3' => 'Artyku&#322; "@titre@" zosta&#322; zatwierdzony do publikacji.',
'info_propose_4' => 'Zosta&#322;e&#347; zaproszony do przegl&#261;du i wyra&#380;enia swojej opinii',
'info_propose_5' => 'w forum, kt&oacute;re jest przyporz&#261;dkowane. Jest ono dost&#281;pne pod adresem :',
'info_publie_01' => 'Artyku&#322; "@titre@" zosta&#322; zatwierdzony przez @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLIKUJE: @titre@',
'info_publie_2' => 'Artyku&#322; opublikowany
-----------------',
'info_rechercher' => 'Szukaj',
'info_rechercher_02' => 'Szukaj:',
'info_remplacer_vignette' => 'Zamie&#324; domy&#347;ln&#261; miniaturk&#281; na wybrane przez ciebie logo&nbsp;:',
'info_retablir_lien' => 'przywr&oacute;c link',
'info_retirer_mot' => 'Usu&#324; to s&#322;owo kluczowe',
'info_retirer_mots' => 'Usu&#324; wszystkie s&#322;owa kluczowe',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'bez tytu&#322;u',
'info_selectionner_fichier' => 'Mo&#380;esz wybra&#263; plik z folderu @upload@',
'info_selectionner_fichier_2' => 'Wybierz plik:',
'info_signature_supprimee' => 'Wpis usuni&#281;ty',
'info_signature_supprimee_erreur' => 'B&#322;&#261;d: ten kod nie odpowiada &#380;adnemu wpisowi',
'info_site_attente' => 'Strona internetowa oczekuj&#261;ca na zatwierdzenie',
'info_site_reference' => 'Strona zlinkowana on-line',
'info_site_refuse' => 'Strona internetowa odrzucona',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Dodaj link',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'usu&#324; winiet&#281;',
'info_symbole_bleu' => 'Symbol <b>niebieski</b> oznacza  <b>notatk&#281;</b>: n.p. wiadomo&#347;&#263; do prywatnego u&#380;ytku.',
'info_symbole_jaune' => 'Symbol <b>&#380;&oacute;&#322;ty</b> oznacza <b>zawiadomienie dla wszystkich redaktor&oacute;w</b>: mo&#380;e by&#263; opublikowana przez wszystkich administrator&oacute;w, i jest widoczna dla wszystkich redaktor&oacute;w.',
'info_symbole_vert' => 'Symbol <b>zielony</b> oznacza <b>wiadomo&#347;ci wymieniane z innymi u&#380;ytkownikami</b> strony.',
'info_syndication' => 'syndykacja&nbsp;:',
'info_syndication_articles' => 'artyku&#322;(y)',
'info_telecharger' => 'Za&#322;aduj ze swojego komputera:',
'info_telecharger_nouveau_logo' => 'Za&#322;aduj nowe logo:',
'info_telecharger_ordinateur' => 'Za&#322;aduj ze swojego komputera:',
'info_tous_resultats_enregistres' => '[wszystkie wyniki s&#261; zapisane]',
'info_tout_afficher' => 'Poka&#380; wszystko',
'info_travaux_texte' => 'Ten serwis nie jest jeszcze skonfigurowany. Zapraszamy p&oacute;&#378;niej...',
'info_travaux_titre' => 'Strona w trakcie budowy',
'info_trop_resultat' => 'Zbyt du&#380;o rezultat&oacute;w "@cherche_mot@" ; spr&oacute;buj sprecyzowa&#263; kryteria wyszukiwania.',
'info_utilisation_messagerie_interne' => 'U&#380;ywasz wewn&#281;trznej poczty w tym serwisie.',
'info_valider_lien' => 'zatwierd&#378; ten link',
'info_verifier_image' => ', prosz&#281; si&#281; upewni&#263;, czy obrazki zosta&#322;y przes&#322;ane prawid&#322;owo.',
'info_vignette_defaut' => 'Domy&#347;lna winieta',
'info_vignette_personnalisee' => 'Miniaturka spersonalizowana',
'info_visite' => 'odwiedziny:',
'info_visites' => 'odwiedziny:',
'info_vos_rendez_vous' => 'Twoje przysz&#322;e spotkania',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Twoje notatki', # MODIF
'item_breve_proposee' => 'Zaproponowany news',

// L
'lien_afficher_icones_seuls' => 'Pokazuj tylko ikonki',
'lien_afficher_texte_icones' => 'POkazuj ikonki i tekst',
'lien_afficher_texte_seul' => 'Pokazuj tylko tekst',
'lien_liberer' => 'uwolnij',
'lien_liberer_tous' => 'uwolnij artyku&#322;y',
'lien_nouvea_pense_bete' => 'NOWA NOTATKA',
'lien_nouveau_message' => 'NOWA WIADOMO&#346;&#262;',
'lien_nouvelle_annonce' => 'NOWE ZAWIADOMIENIE',
'lien_petitions' => 'OG&#321;OSZENIE',
'lien_popularite' => 'popularno&#347;&#263;: @popularite@%',
'lien_racine_site' => 'RDZE&#323; STRONY',
'lien_reessayer' => 'spr&oacute;buj ponownie',
'lien_repondre_message' => 'Odpowiedz na t&#281; wiadomo&#347;&#263;',
'lien_supprimer' => 'usu&#324;',
'lien_tout_afficher' => 'Poka&#380; wszystko',
'lien_visite_site' => 'odwied&#378; stron&#281;',
'lien_visites' => '@visites@ odwiedzin',
'lien_voir_auteur' => 'Sprawd&#378; autora',
'ligne' => 'Linia',
'login' => 'Po&#322;&#261;czenie',
'login_acces_prive' => 'dost&#281;p do obszaru prywatnego',
'login_autre_identifiant' => 'zaloguj u&#380;ywaj&#261;c innego loginu',
'login_cookie_accepte' => 'Zmie&#324; ustawienia Twojej przegl&#261;darki, aby je akceptowa&#322;a (przynajmniej dla tej strony).',
'login_cookie_oblige' => 'Aby m&oacute;c zalogowa&#263; si&#281; bezpiecznie do tej strony, musicie zaakceptowa&#263; cookies.',
'login_deconnexion_ok' => 'Roz&#322;&#261;czanie zako&#324;czono.',
'login_erreur_pass' => 'B&#322;&#261;d has&#322;a.',
'login_espace_prive' => 'obszar prywatny',
'login_identifiant_inconnu' => 'Login &laquo; @login@ &raquo; nieznany.',
'login_login' => 'Login:',
'login_login2' => 'Login (identyfikator)&nbsp;:',
'login_login_pass_incorrect' => '(Z&#322;y login lub has&#322;o).',
'login_motpasseoublie' => 'zapomnia&#322;e&#347; has&#322;a?',
'login_non_securise' => 'Uwaga ten formularz nie jest bezpieczny.
   Je&#347;li nie chcesz aby Twoje has&#322;o zosta&#322;o przechwycone w sieci
   , w&#322;&#261;cz JavaScript w Twojej przegl&#261;darce i',
'login_nouvelle_tentative' => 'Nowa pr&oacute;ba',
'login_par_ici' => 'Jeste&#347; zarejestrowany... t&#281;dy...',
'login_pass2' => 'Has&#322;o:',
'login_preferez_refuser' => '<b>Je&#347;li wolisz nie korzysta&#263; z cookies</b>, jest inna (mniej bezpieczna) metoda do dyspozycji&nbsp;:',
'login_recharger' => 'prze&#322;aduj stron&#281;',
'login_rester_identifie' => 'Pozosta&#324; zalogowany kilka dni',
'login_retour_public' => 'Powr&oacute;t do strony publicznej',
'login_retour_site' => 'Powr&oacute;t do strony publicznej',
'login_retoursitepublic' => 'Powr&oacute;t do strony publicznej',
'login_sans_cookiie' => 'Identyfikacja bez cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'rejestracja',
'login_test_navigateur' => 'test przegl&#261;darki/&#322;&#261;cz ponownie',
'login_verifiez_navigateur' => '(Sprawd&#378; czy Twoja przegl&#261;darka nie zapami&#281;ta&#322;a has&#322;a...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'ukryj tlumaczenia',
'module_fichiers_langues' => 'Pliki j&#281;zykowe',

// N
'navigateur_pas_redirige' => 'Je&#347;li twoja przegl&#261;darka ci&#281; nie przekierowa&#322;a, kliknij tutaj, &#380;eby kontynuowa&#263;.',
'numero' => 'Numer',

// O
'occurence' => 'Wyst&#261;pienie',
'onglet_affacer_base' => 'Usu&#324; baz&#281; danych',
'onglet_auteur' => 'Autor',
'onglet_contenu_site' => 'Zawarto&#347;&#263; strony',
'onglet_evolution_visite_mod' => 'Ewolucja',
'onglet_fonctions_avances' => 'Funkcje zaawansowane',
'onglet_informations_personnelles' => 'Informacje osobiste',
'onglet_interactivite' => 'Interaktywno&#347;&#263;',
'onglet_messagerie' => 'Wiadomo&#347;ci',
'onglet_messages_internes' => 'Wiadomo&#347;ci wewn&#281;trzne',
'onglet_messages_publics' => 'Wiadomo&#347;ci publiczne',
'onglet_messages_vide' => 'Wiadomo&#347;ci bez tekstu',
'onglet_origine_visites' => 'Wizyty z URL-i',
'onglet_repartition_debut' => 'od pocz&#261;tku',
'onglet_repartition_lang' => 'Porz&#261;dkowanie wg j&#281;zyk&oacute;w',
'onglet_repartition_rubrique' => 'Roz&#322;o&#380;enie dzia&#322;&oacute;w',
'onglet_save_restaur_base' => 'Backup/zapisywanie bazy danych',
'onglet_vider_cache' => 'Opr&oacute;&#380;nij cache',

// P
'pass_choix_pass' => 'Prosz&#281; wybra&#263; swoje nowe has&#322;o:',
'pass_erreur' => 'B&#322;&#261;d',
'pass_erreur_acces_refuse' => '<b>B&#322;&#261;d:</b> nie masz ju&#380; dost&#281;pu do tej strony.',
'pass_erreur_code_inconnu' => '<b>B&#322;&#261;d :</b> ten kod nie odpowiada, &#380;adnemu z u&#380;ytkownik&oacute;w, kt&oacute;rzy maj&#261; dost&#281;p do tej strony.',
'pass_erreur_non_enregistre' => '<b>B&#322;&#261;d :</b> adres <tt>@email_oubli@</tt> nie jest zarejestrowany na tej stronie.',
'pass_erreur_non_valide' => '<b>B&#322;&#261;d :</b> e-mail <tt>@email_oubli@</tt> nie jest prawid&#322;owy!',
'pass_erreur_probleme_technique' => '<b>B&#322;ad :</b> e-mail nie m&oacute;g&#322; by&#263; wys&#322;any z powodu problem&oacute;w technicznych.',
'pass_espace_prive_bla' => 'Strefa prywatna tego serwisu jest dost&#281;na
  dla zapisanych u&#380;ytkownik&oacute;w. Jako zarejestrowany u&#380;ytkownik,
  b&#281;dziesz m&oacute;g&#322; czyta&#263; artyku&#322;y, kt&oacute;re s&#261; w trakcie redagowania,
  proponowa&#263; artyku&#322;y i bra&#263; udzia&#322; w dyskusjach na forum.',
'pass_forum_bla' => 'Chcesz wzi&#261;&#263; udzia&#322; w forum
  zarezerwowanym dla zarejestrowanych u&#380;ytkownik&oacute;w.',
'pass_indiquez_cidessous' => 'Wpisz poni&#380;ej adres e-mail pod jakim
by&#322;e&#347; zarejestrowany poprzednio.
Otrzymasz e-maila wyja&#347;niaj&#261;cego jak
mo&#380;esz odzyska&#263; sw&oacute;j dost&#281;p.',
'pass_mail_passcookie' => '(to jest automatyczna wiadomo&#347;&#263;)

Aby odzyska&#263; dost&#281;p do strony
@nom_site_spip@ (@adresse_site@)

Prosz&#281; wej&#347;&#263; na stron&#281;:

    @sendcookie@

Po wpisaniu nowego has&#322;a
mo&#380;na ponownie po&#322;&#261;czy&#263; si&#281; ze stron&#261;.
',
'pass_mot_oublie' => 'Zapomniane has&#322;o',
'pass_nouveau_enregistre' => 'Twoje nowe has&#322;o zosta&#322;o zapisane.',
'pass_nouveau_pass' => 'Nowe has&#322;o',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Zapomnienie has&#322;a',
'pass_quitter_fenetre' => 'Zamknij okno',
'pass_rappel_login' => 'Przypomnienie : tw&oacute;j identyfikator (login) to &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Otrzymasz e-mail wyja&#347;niaj&#261;cy jak mo&#380;esz odzyska&#263; dost&#281;p do strony.',
'pass_retour_public' => 'Powr&oacute;t do strony publicznej',
'pass_rien_a_faire_ici' => 'Nie ma tu nic do zrobienia.',
'pass_vousinscrire' => 'Zapisa&#347; si&#281; w tym serwisie',
'precedent' => 'poprzedni',
'previsualisation' => 'Podgl&#261;d',
'previsualiser' => 'W&#322;&#261;cz podgl&#261;d',

// R
'retour' => 'Powr&oacute;t',

// S
'spip_conforme_dtd' => 'SPIP uznaje ten dokument za zgodny z jego DOCTYPE :',
'squelette' => 'szkielet',
'squelette_inclus_ligne' => 'szkielet zainkludowany, linia',
'squelette_ligne' => 'szkielet, linia',
'stats_visites_et_popularite' => '@visites@ odwiedzin; popularno&#347;&#263;: @popularite@',
'suivant' => 'nast&#281;pny',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@&nbsp;bytes',
'texte_actualite_site_1' => 'Kiedy poznasz interfejs, kliknij na &laquo;',
'texte_actualite_site_2' => 'kompletny interfejs',
'texte_actualite_site_3' => '&raquo; aby uruchomi&#263; wi&#281;cej mo&#380;liwo&#347;ci.',
'texte_creation_automatique_vignette' => 'W tym serwisie, uruchomione jest generowanie minitaurek.Je&#347;li instalujecie za po&#347;rednictwem tego formularza pliki graficzne w formatach @gd_formats@, zostan&#261; one uzupe&#322;nione o minitaurk&#281;, o miniaturk&#281; w wielko&#347;ci maksymalnej: @taille_preview@&nbsp;pixels.',
'texte_documents_associes' => 'Nast&#281;puj&#261;ce dokumenty s&#261; zwi&#261;zane z artyku&#322;em,
    ale nie zosta&#322;y bezpo&#347;rednio do niego
    do&#322;&#261;czone. Zale&#380;nie od uk&#322;adu stron publicznych,
    b&#281;d&#281; mog&#322;y pojawi&#263; si&#281; na nich jako za&#322;&#261;czniki.',
'texte_erreur_mise_niveau_base' => 'B&#322;&#261;d bazy danych zaistnia&#322;y w trakcie uaktualniania.
  Obrazek <b>@fichier@</b> nie przeszed&#322; (artyku&#322; @id_article@).
  Zapisz te dane, i spr&oacute;buj ponownego uaktualnienia,
a nast&#281;pnie sprawd&#378; czy obrazki pojawiaj&#261; si&#281; zawsze w artyku&#322;ach.',
'texte_erreur_visiteur' => 'Pr&oacute;bujesz dosta&#263; si&#281; do panelu administracyjnego za pomoc&#261; loginu, kt&oacute;ry na to nie pozwala.',
'texte_inc_auth_1' => 'Jeste&#347; zalogowany za pomoc&#261;
  loginu <b>@auth_login@</b>, ale nie istnieje on (ju&#380;) w bazie danych. 
  Spr&oacute;buj si&#281;', # MODIF
'texte_inc_auth_2' => 'po&#322;&#261;czy&#263;',
'texte_inc_auth_3' => ', opuszczj&#261;c ewentualnie przegl&#261;dark&#281;
  i w&#322;&#261;czaj&#261;c j&#261; na powr&oacute;t.',
'texte_inc_config' => 'Zmiany dokonane na tych stronach znacz&#261;co wp&#322;yn&#261; na
 funkcjonowanie Twojego serwisu. Radzimy nie zatwierdza&#263; tych zmian do momentu, w kt&oacute;rym nie b&#281;dziecie
 dobrze obeznani z funkcjonowaniem systemu SPIP. <br /><br /><b>Najbardziej
 zalecamy, poproszenie o dokonanie zmian g&#322;&oacute;wnego adminsitratora serwisu.</b>',
'texte_inc_meta_1' => 'System nie mo&#380;e zapisa&#263; plik&oacute;w <code>@fichier@</code>. Jako administrator strony,',
'texte_inc_meta_2' => 'sprawd&#378; pozwolenia zapisu',
'texte_inc_meta_3' => 'dla katalogu <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'redakcja w toku',
'texte_statut_poubelle' => 'do kosza',
'texte_statut_propose_evaluation' => 'zaproponowany do oceny',
'texte_statut_publie' => 'opublikowany online',
'texte_statut_refuse' => 'odrzucony',
'titre_ajouter_mot_cle' => 'DODAJ S&#321;OWO KLUCZOWE:',
'titre_breve_proposee' => 'News zatwierdzony',
'titre_breve_publiee' => 'News opublikowany',
'titre_breve_refusee' => 'News odrzucony',
'titre_cadre_raccourcis' => 'SKR&Oacute;TY :',
'titre_changer_couleur_interface' => 'Zmiana koloru interfejsu',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Mo&#380;esz edytowa&#263; ten artyku&#322;',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'Pomoc do tego elementu',
'titre_image_auteur_supprime' => 'Autor usuni&#281;ty',
'titre_image_redacteur' => 'Redaktor bez dost&#281;pu',
'titre_image_redacteur_02' => 'Redaktor',
'titre_image_visiteur' => 'Odwiedzaj&#261;cy',
'titre_joindre_document' => 'ZA&#321;&#260;CZ DOKUMENT',
'titre_liens_entrants' => 'Linki wej&#347;ciowe',
'titre_mots_cles' => 'S&#321;OWA KLUCZOWE',
'titre_probleme_technique' => 'Uwaga: problem techniczny (serwer SQL) blokuje dost&#281;p do tej cz&#281;&#347;ci strony. Dzi&#281;kujemy za zrozumienie.',
'titre_publier_document' => 'PUBLIKUJ DOKUMENT W TYM DZIALE',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Statystyki strony',
'titre_titre_document' => 'Tytu&#322; dokumentu:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(artyku&#322; wzorcowy)',

// Z
'zbug_balise_b_aval' => '&nbsp;: balise B en aval',
'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n\'existe pas', # MODIF
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'p&#281;tla',
'zbug_boucle_recursive_undef' => 'p&#281;tla rekursywna nie zosta&#322;a zdefiniowana', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Pole @champ@ jest bez p&#281;tli',
'zbug_champ_hors_motif' => 'Pole @champ@ jest poza p&#281;tl&#261; @motif@', # MODIF
'zbug_code' => 'kod',
'zbug_critere_inconnu' => 'nieznane kryterium @critere@', # MODIF
'zbug_distant_interdit' => 'operacja niedozwolona w zewn&#281;trznej bazie', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
'zbug_doublon_table_sans_index' => 'podw&oacute;jny wpis w tablicy bez indeksu', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: podw&oacute;jna definicja', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: brakuje znacznika zamykaj&#261;cego', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Sk&#322;adnia p&#281;tli (boucle) nieprawid&#322;owa', # MODIF
'zbug_erreur_compilation' => 'B&#322;&#261;d kompilacji',
'zbug_erreur_execution_page' => 'b&#322;&#261;d w wykonaniu strony', # MODIF
'zbug_erreur_filtre' => 'B&#322;&#261;d : filtr <b>&laquo; @filtre@ &raquo;</b> nie zdefiniowany', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} stosuje si&#281; wy&#322;&#261;cznie do p&#281;tli (FORUMS) i (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'B&#322;&#261;d (b&#322;&#281;dy) w szkielecie',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => 'B&#322;&#261;d na stronie',
'zbug_inversion_ordre_inexistant' => 'odwr&oacute;cenie nieistniej&#261;cego uporz&#261;dkowania', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION bez kryterium {pagination} lub u&#380;yta w p&#281;tli rekursywnej', # MODIF
'zbug_parametres_inclus_incorrects' => 'Z&#322;e parametry za&#322;&#261;czenia (include)', # MODIF
'zbug_profile' => 'Czas przeliczania: @time@',
'zbug_resultat' => 'wynik',
'zbug_serveur_indefini' => 'serwer SQL niezdefiniowany', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Tabela SQL &laquo; @table@ &raquo; nieznana',
'zxml_connus_attributs' => 'znane atrybuty',
'zxml_de' => 'z',
'zxml_inconnu_attribut' => 'atrybut nieznany',
'zxml_inconnu_balise' => 'znacznik nieznany',
'zxml_inconnu_entite' => 'nieznana warto&#347;&#263;',
'zxml_inconnu_id' => 'ID nieznany',
'zxml_mais_de' => 'ale z',
'zxml_non_conforme' => 'nie jest zgodny',
'zxml_non_fils' => 'nie jest z',
'zxml_nonvide_balise' => 'znacznik nie jest pusty',
'zxml_obligatoire_attribut' => 'nieobecny atrybut obowi&#261;zkowy',
'zxml_succession_fils_incorrecte' => 'niepoprawne dziedziczenie',
'zxml_survoler' => 'najed&#378; wska&#378;nikiem aby zobaczy&#263; poprawne',
'zxml_valeur_attribut' => 'warto&#347;&#263; artybutu',
'zxml_vide_balise' => 'pusty znacznik',
'zxml_vu' => 'widziany wcze&#347;niej'
);

?>
